Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var EPSILON = math.Nextafter(1, 2) - 1
var ErrVectorInvalidDimension = errors.New("Vectors' dimensions are not of the expected size.")
var ErrVectorNotSameSize = errors.New("Vectors are not the same size.")
Functions ¶
Types ¶
type Vector ¶
type Vector []float64
func NewWithValues ¶
func (Vector) Do ¶
Iterates through the elements of this vector and for each element invokes the function.
func (Vector) DoWithIndex ¶
Iterates through the elements of this vector and for each element invokes the function with index.
Click to show internal directories.
Click to hide internal directories.